# cfgnlog

This is a simple packge to add configuration and log files for your application.
It was initially created as part of a prototype for Ymir Systems, but now has been separated to stand on it's own.

- XDG Compliant by default.
- Configruation files are saved as JSON.
- Log messages are prepended with a timestamp.
- Callback methods may be registered for activation on updates.
